@@ -23,7 +23,7 @@
 
 use rand_core::SeedableRng;
 
-use snarkvm_fields::PrimeField;
+use snarkvm_fields::{PoseidonMDSField, PrimeField};
 use snarkvm_gadgets::{
     fields::FpGadget,
     traits::{alloc::AllocGadget, fields::FieldGadget},
@@ -37,7 +37,7 @@ use crate::fiat_shamir::{
 
 #[derive(Clone)]
 /// the gadget for Poseidon sponge
-pub struct PoseidonSpongeVar<F: PrimeField> {
+pub struct PoseidonSpongeVar<F: PrimeField + PoseidonMDSField> {
     /// number of rounds in a full-round operation
     pub(super) full_rounds: u32,
     /// number of rounds in a partial-round operation
@@ -60,7 +60,7 @@ pub struct PoseidonSpongeVar<F: PrimeField> {
     mode: PoseidonSpongeState,
 }
 
-impl<F: PrimeField> PoseidonSpongeVar<F> {
+impl<F: PrimeField + PoseidonMDSField> PoseidonSpongeVar<F> {
     fn apply_s_box<CS: ConstraintSystem<F>>(
         &self,
         mut cs: CS,
@@ -190,18 +190,14 @@ impl<F: PrimeField> PoseidonSpongeVar<F> {
     }
 }
 
-impl<F: PrimeField> AlgebraicSpongeVar<F, PoseidonSponge<F>> for PoseidonSpongeVar<F> {
+impl<F: PrimeField + PoseidonMDSField> AlgebraicSpongeVar<F, PoseidonSponge<F>> for PoseidonSpongeVar<F> {
     fn new<CS: ConstraintSystem<F>>(mut cs: CS) -> Self {
         // Requires F to be Alt_Bn128Fr
-        let full_rounds = 8;
-        let partial_rounds = 31;
-        let alpha = 17;
+        let full_rounds = F::poseidon_number_full_rounds();
+        let partial_rounds = F::poseidon_number_partial_rounds();
+        let alpha = F::poseidon_alpha();
 
-        let mds = vec![
-            vec![F::one(), F::zero(), F::one()],
-            vec![F::one(), F::one(), F::zero()],
-            vec![F::zero(), F::one(), F::one()],
-        ];
+        let mds = F::poseidon_mds_matrix();
 
         let mut ark = Vec::new();
         let mut ark_rng = rand_chacha::ChaChaRng::seed_from_u64(123456789u64);
@@ -308,7 +304,7 @@ mod tests {
     use rand::Rng;
     use rand_chacha::ChaChaRng;
 
-    use snarkvm_curves::bls12_377::Fr;
+    use snarkvm_curves::bls12_377::Fq;
     use snarkvm_gadgets::traits::eq::EqGadget;
     use snarkvm_r1cs::TestConstraintSystem;
     use snarkvm_utilities::rand::UniformRand;
@@ -317,8 +313,8 @@ mod tests {
 
     use super::*;
 
-    type Sponge = PoseidonSponge<Fr>;
-    type SpongeVar = PoseidonSpongeVar<Fr>;
+    type Sponge = PoseidonSponge<Fq>;
+    type SpongeVar = PoseidonSpongeVar<Fq>;
 
     const MAX_ELEMENTS: usize = 100;
     const ITERATIONS: usize = 100;
@@ -328,14 +324,14 @@ mod tests {
         let mut rng = ChaChaRng::seed_from_u64(123456789u64);
 
         for i in 0..ITERATIONS {
-            let mut cs = TestConstraintSystem::<Fr>::new();
+            let mut cs = TestConstraintSystem::<Fq>::new();
 
             // Create a new algebraic sponge.
             let mut sponge = Sponge::new();
 
             // Generate random elements to absorb.
             let num_elements: usize = rng.gen_range(0..MAX_ELEMENTS);
-            let elements: Vec<_> = (0..num_elements).map(|_| Fr::rand(&mut rng)).collect();
+            let elements: Vec<_> = (0..num_elements).map(|_| Fq::rand(&mut rng)).collect();
 
             // Absorb the random elements.
             sponge.absorb(&elements);
@@ -368,7 +364,7 @@ mod tests {
         let mut rng = ChaChaRng::seed_from_u64(123456789u64);
 
         for i in 0..ITERATIONS {
-            let mut cs = TestConstraintSystem::<Fr>::new();
+            let mut cs = TestConstraintSystem::<Fq>::new();
 
             // Create a new algebraic sponge.
             let mut sponge = Sponge::new();
@@ -378,7 +374,7 @@ mod tests {
 
             // Generate random elements to absorb.
             let num_elements: usize = rng.gen_range(0..MAX_ELEMENTS);
-            let elements: Vec<_> = (0..num_elements).map(|_| Fr::rand(&mut rng)).collect();
+            let elements: Vec<_> = (0..num_elements).map(|_| Fq::rand(&mut rng)).collect();
 
             let mut element_gadgets = vec![];
             for (j, element) in elements.iter().enumerate() {
